.. Developers should add in this file, during each release cycle, information
.. about important changes they've made, in a summary format that's meant for
.. end users.  For each release we normally have three sections: features,  bug
.. fixes and api breakage.
.. Please remember to credit the authors of the contributions by name,
.. especially when they are new users or developers who do not regularly
.. participate  in IPython's development.

.. _whatsnew_index:

=====================
What's new in Nitime
=====================

This section documents the changes that have been made in various versions of
Nitime:

.. toctree::
   :maxdepth: 1

   version0.7
   version0.6
   version0.5
   version0.4
   version0.3


Users should consult these pages to learn about new features, bug
fixes and backwards incompatibilities. Developers should summarize the
development work they do here.
